"""
APIs to help with programmatically parsing the MLAgility report
"""

from typing import Dict
import pandas as pd


def get_dict(report_csv: str, column: str) -> Dict[str, str]:
    """
    Returns a dictionary where the keys are model names and the values are the values of
    a given column in a report.csv file.

    args:
     - report_csv: path to a report.csv file generated by benchit
     - column: name of a column in the report.csv file whose values will be used to
        populate the dictionary
    """

    # Open the MLAgility report as a dataframe
    dataframe = pd.read_csv(report_csv)

    # Convert to dictionary
    return pd.Series(dataframe[column].values, index=dataframe.model_name).to_dict()
